<?php
/*
Plugin Name: WLW - Whatsapp botón flotante
Description: Añade un botón de Whatsapp flotante en todas las páginas.
Version: 2.2
Requires at least: 5.0
Requires PHP: 7.2
Author: Christian Cabrero
Author URI: https://cabrero.ch
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: cabrero-plugins
Domain Path: /languages
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// Añadimos el HTML en el pie de pagina
function add_whatsapp(){
    $options = get_option('wlw_whatsapp_flotante_options');
    $telefono = isset($options['telefono']) ? $options['telefono'] : '';
    $numero_whatsapp = $telefono;
    echo '<a id="whatsapp-flotante" href="https://api.whatsapp.com/send?phone=' . urlencode($numero_whatsapp) . '&text=Hola,%20tengo%20una%20consulta.%20%C2%BFMe%20pueden%20atender?" target="_blank"><img src="'.plugin_dir_url( __FILE__ ).'img/whatsapp.png"></a>';
}
add_action('wp_footer', 'add_whatsapp');


//Carga el CSS
function myplugin_scripts() {
    wp_register_style( 'estilos-whatsapp-wlw', plugin_dir_url( __FILE__ ).'css/wlw-whatsapp-flotante.css' );
    wp_enqueue_style( 'estilos-whatsapp-wlw' );
}
add_action( 'wp_enqueue_scripts', 'myplugin_scripts' );

// añadir un menú para poder cambiar el teléfono del botón

add_action('admin_menu', 'wlw_whatsapp_flotante_menu');

function wlw_whatsapp_flotante_menu()
{
    add_menu_page(
        'WLW Whatsapp Flotante',
        'WLW Whatsapp Flotante',
        'administrator',
        'wlw-whatsapp-flotante-wp-admin',
        'displayAdminDashboardWhatsapp',
        'dashicons-whatsapp',
        20
    );
}

function displayAdminDashboardWhatsapp()
{
    ?>
    <h1>WLW Whatsapp Flotante</h1>
    <form action="options.php" method="post">
        <?php
        settings_fields('wlw_whatsapp_flotante_options');
        do_settings_sections('wlw_whatsapp_flotante_options');
        submit_button('Guardar cambios');
        ?>
    </form>
    <?php
}

function wlw_whatsapp_flotante_settings_init()
{
    register_setting('wlw_whatsapp_flotante_options', 'wlw_whatsapp_flotante_options');
    add_settings_section('wlw_whatsapp_flotante_section', '', 'wlw_whatsapp_flotante_section_cb', 'wlw_whatsapp_flotante_options');
    add_settings_field('wlw_whatsapp_flotante_telefono', 'Teléfono', 'wlw_whatsapp_flotante_telefono_cb', 'wlw_whatsapp_flotante_options', 'wlw_whatsapp_flotante_section');
}

function wlw_whatsapp_flotante_section_cb()
{
    echo '<p>Introduce el teléfono al que quieres que se envíen los mensajes de Whatsapp.</p>';
}

function wlw_whatsapp_flotante_telefono_cb()
{
    $options = get_option('wlw_whatsapp_flotante_options');
    $telefono = isset($options['telefono']) ? $options['telefono'] : '';
    echo "<input id='wlw_whatsapp_flotante_telefono' name='wlw_whatsapp_flotante_options[telefono]' type='text' value='$telefono' />";
}
// muestra un mensaje de éxito al guardar el número
function wlw_whatsapp_flotante_save_success_message()
{
    add_settings_error(
        'wlw_whatsapp_flotante_messages',
        'wlw_whatsapp_flotante_message',
        __('Número guardado.', 'wlw-whatsapp-flotante'),
        'updated'
    );
}

function wlw_whatsapp_flotante_display_admin_messages()
{
    settings_errors('wlw_whatsapp_flotante_messages');
}

add_action('admin_init', 'wlw_whatsapp_flotante_settings_init');
// muestra un mensaje de éxito al guardar el número
add_action('admin_notices', 'wlw_whatsapp_flotante_display_admin_messages');
add_action('update_option_wlw_whatsapp_flotante_options', 'wlw_whatsapp_flotante_save_success_message');

// Eliminar la opción al desinstalar el plugin
register_uninstall_hook(__FILE__, 'wlw_whatsapp_flotante_uninstall');

function wlw_whatsapp_flotante_uninstall()
{
    delete_option('wlw_whatsapp_flotante_options');
}